<?php
/*
Plugin Name: Eksport kategorii
Description: Moduł do eksportu kategorii z WooCommerce do pliku.
Version: 1.0.0
Author: PKO Leasing
*/

add_action('admin_menu', 'add_export_categories_menu');

function add_export_categories_menu() {
    add_menu_page('Eksport kategorii', 'Eksport kategorii', 'manage_options', 'eksport-kategorii', 'export_product_categories_to_csv');
}

function export_product_categories_to_csv() {
    if( !current_user_can('manage_options') ) return;

    // Wyłączenie wyświetlania błędów
    error_reporting(0);
    ini_set('display_errors', 0);

    // Wyczyść bufor wyjściowy, aby usunąć wszystkie wcześniejsze treści
    while (ob_get_level()) {
        ob_end_clean();
    }

    // Pobranie dynamicznej nazwy serwisu
    $site_name = sanitize_file_name(get_bloginfo('name'));

    // Pobranie bieżącej daty i czasu w formacie YYYYMMDDHH24MISS
    $current_datetime = date('YmdHis');

    // Zmienna dla kategorii WooCommerce
    $taxonomy = 'product_cat'; 
    $categories = get_terms(array(
        'taxonomy'   => $taxonomy,
        'hide_empty' => false,
    ));

    // Sortowanie kategorii po ID kategorii rosnąco
    usort($categories, function($a, $b) {
        return $a->term_id - $b->term_id;
    });

    // Ustawienie nagłówków, aby przeglądarka rozpoznała plik jako CSV
    $filename = 'Kategorie_' . $site_name . '_' . $current_datetime . '.csv';
    header('Content-Type: application/vnd.ms-excel');
    header('Content-Disposition: attachment;filename=' . $filename);
    header('Cache-Control: max-age=0');

    // Otwarcie strumienia wyjścia
    $output = fopen('php://output', 'w');
    fprintf($output, chr(0xEF).chr(0xBB).chr(0xBF)); // Dodanie BOM dla poprawnego wyświetlania znaków w Excelu

    // Nagłówki kolumn CSV
    fputcsv($output, array('ID kategorii', 'Nazwa kategorii', 'ID nadrzędnej kategorii', 'Nazwa nadrzędnej kategorii', 'Poziom zagnieżdżenia'), ';');

    // Dodanie do pliku ID, nazwy kategorii, ID nadrzędnej kategorii, nazwy nadrzędnej kategorii oraz poziomu zagnieżdżenia
    foreach ($categories as $category) {
        $parent_name = $category->parent == 0 ? 'Brak' : get_term($category->parent)->name;
        fputcsv($output, array($category->term_id, $category->name, $category->parent, $parent_name, get_category_level($category)), ';');
    }

    // Zamknięcie pliku CSV
    fclose($output);
    exit;
}

function get_category_level($category) {
    $level = 0;
    while ($category->parent != 0) {
        $category = get_term($category->parent);
        $level++;
    }
    return $level;
}